'use client'

import { useEffect, useRef, useState } from 'react'
import { FiBell, FiVolume2, FiVolumeX } from 'react-icons/fi'
import { useNotificationStore } from '@/store/useNotificationStore'
import { waiterService } from '@/services/api'

export default function Notifications() {
  const message = useNotificationStore((state) => state.message)
  const hideNotification = useNotificationStore((state) => state.hideNotification)
  const soundEnabled = useNotificationStore((state) => state.soundEnabled)
  const toggleSound = useNotificationStore((state) => state.toggleSound)
  const showNotification = useNotificationStore((state) => state.showNotification)
  const audioRef = useRef<HTMLAudioElement | null>(null)
  const [audioInitialized, setAudioInitialized] = useState(false)
  const [lastCallId, setLastCallId] = useState<number | null>(null)
  const timerRef = useRef<NodeJS.Timeout | null>(null)

  // Mesaj değiştiğinde timer'ı yeniden başlat
  useEffect(() => {
    if (message) {
      // Önceki timer'ı temizle
      if (timerRef.current) {
        clearTimeout(timerRef.current)
      }

      // Yeni timer başlat
      timerRef.current = setTimeout(() => {
        hideNotification()
      }, 10000)
    }

    // Component unmount olduğunda timer'ı temizle
    return () => {
      if (timerRef.current) {
        clearTimeout(timerRef.current)
      }
    }
  }, [message, hideNotification])

  // Ses başlatma işlemi
  const initializeAudio = async () => {
    try {
      if (!audioRef.current) {
        audioRef.current = new Audio('/notification.mp3')
        audioRef.current.volume = 1 // Ses seviyesini maksimuma çıkardık
      }

      await audioRef.current.play()
      audioRef.current.pause()
      audioRef.current.currentTime = 0
      
      setAudioInitialized(true)
    } catch (err) {
      console.error('Ses başlatma hatası:', err)
    }
  }

  // Ses çalma işlemi
  const playNotificationSound = async () => {
    if (!audioRef.current || !soundEnabled) return

    try {
      const newAudio = new Audio('/notification.mp3')
      newAudio.volume = 1
      await newAudio.play()
    } catch (err) {
      console.error('Ses çalma hatası:', err)
      setAudioInitialized(false)
    }
  }

  // Kullanıcı etkileşiminde ses iznini al
  useEffect(() => {
    const handleInteraction = async () => {
      await initializeAudio()
      document.removeEventListener('click', handleInteraction)
      document.removeEventListener('touchstart', handleInteraction)
      document.removeEventListener('keydown', handleInteraction)
    }

    document.addEventListener('click', handleInteraction)
    document.addEventListener('touchstart', handleInteraction)
    document.addEventListener('keydown', handleInteraction)

    return () => {
      document.removeEventListener('click', handleInteraction)
      document.removeEventListener('touchstart', handleInteraction)
      document.removeEventListener('keydown', handleInteraction)
    }
  }, [])

  // Garson çağrılarını kontrol et
  useEffect(() => {
    const checkWaiterCalls = async () => {
      try {
        const response = await waiterService.index()
        const pendingCalls = response.data.pending_calls || []
        
        if (pendingCalls.length > 0) {
          const lastCall = pendingCalls[pendingCalls.length - 1]
          
          // Yeni çağrı kontrolü
          if (lastCall.id !== lastCallId) {
            showNotification(`${lastCall.table?.name} sizi çağırıyor!`, 'waiter')
            setLastCallId(lastCall.id)
            await playNotificationSound()
          }
        }
      } catch (error) {
        console.error('Garson çağrıları kontrol edilirken hata:', error)
      }
    }

    // İlk kontrol
    checkWaiterCalls()

    const interval = setInterval(checkWaiterCalls, 5000)
    return () => clearInterval(interval)
  }, [showNotification, soundEnabled, lastCallId])

  if (!message) return null

  return (
    <div className="fixed bottom-6 right-6 z-[9999]">
      <div className="animate-slide-up bg-white dark:bg-slate-800 rounded-2xl shadow-2xl 
                   border border-purple-100/50 dark:border-purple-500/10
                   backdrop-blur-xl p-4 max-w-sm w-full">
        <div className="flex items-center gap-4">
          <div className="flex-shrink-0 w-12 h-12 rounded-xl 
                       bg-gradient-to-br from-fuchsia-500 via-purple-500 to-purple-600
                       flex items-center justify-center shadow-lg
                       ring-4 ring-purple-500/10">
            <FiBell className="w-6 h-6 text-white animate-pulse" />
          </div>

          <div className="flex-1 min-w-0">
            <div className="flex items-center justify-between mb-1">
              <h5 className="font-semibold text-slate-900 dark:text-white">
                Garson Çağrısı
              </h5>
              <button
                onClick={toggleSound}
                className="p-1 hover:bg-slate-100 dark:hover:bg-slate-700 rounded-lg transition-colors"
              >
                {soundEnabled ? (
                  <FiVolume2 className="w-4 h-4 text-slate-600 dark:text-slate-400" />
                ) : (
                  <FiVolumeX className="w-4 h-4 text-slate-600 dark:text-slate-400" />
                )}
              </button>
            </div>
            <p className="text-sm text-slate-600 dark:text-slate-300 truncate">
              {message}
            </p>
          </div>
        </div>
      </div>
    </div>
  )
} 